+++
title = "TOC with TODO disabled"
description = """
  No TODO states are prefixed to the headings -- neither in the body, nor
  in the TOC.
  """
tags = ["export-option", "toc", "todo", "disable"]
draft = false
+++

<div class="ox-hugo-toc toc">
<div></div>

<div class="heading">Table of Contents</div>

- [No TODO state](#no-todo-state)
- [Something to do](#something-to-do)
- [Something done](#something-done)

</div>
<!--endtoc-->

<style>
.org-todo {
    font-size: 0.8em;
    font-weight: 700;
}
/* *** Org TODO set to TODO state */
.org-todo.todo {
    color: #e60000;
}
/* *** Org TODO set to DONE state */
.org-todo.done {
    color: green;
}
</style>


## No TODO state {#no-todo-state}


## Something to do {#something-to-do}


## Something done {#something-done}
